Package 'OSCA.multisample'

Title: OSCA for Multiple Samples
Description: Deploys the multi-sample analysis chapters for the "Orchestrating Single Cell Analysis with Bioconductor" book. This describes the handling of multiple samples in a single-cell RNA-seq analysis, starting with integration of multiple datasets into a common space for consistent analyses, differential expression comparisons between conditions based on pseudo-bulk samples, and differential abundance analyses for cell subpopulations. It is intended for readers who are already familiar with basic single-cell analyses, possibly after reading some of the prior books in this collection.
Authors: Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Alan O'Callaghan [cre]
Maintainer: Alan O'Callaghan <[email protected]>
License: CC BY
Version: 1.21.0
Built: 2026-05-29 09:41:16 UTC
Source: https://github.com/bioc/OSCA.multisample

Help Index